# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Socket6
Version:	0.29
Release:	17.%{__distinit}%{__distvers}
Summary:	IPv6 related part of the C socket.h defines and structure manipulators
License:	BSD-3-Clause
URL:		https://metacpan.org/release/Socket6
Source0:	https://cpan.metacpan.org/modules/by-module/Socket6/Socket6-%{version}.tar.gz
Patch0:		Socket6-0.29-remove_support_of_gethostname2.patch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Config)
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(DynaLoader)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
# Test Suite
BuildRequires:	perl(Socket)
BuildRequires:	perl(Test)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

# Don't "provide" private Perl libs
%{?perl_default_filter}

%description
This module supports getaddrinfo() and getnameinfo() to intend to enable
protocol independent programming. If your environment supports IPv6, IPv6
related defines such as AF_INET6 are included.

%prep
%setup -q -n Socket6-%{version}

# Drop support for deprecated gethostbyname2
# https://src.fedoraproject.org/rpms/perl-Socket6/pull-request/2
%patch -P 0 -p1

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc ChangeLog README gailookup.pl
%{perl_vendorarch}/Socket6.pm
%{perl_vendorarch}/auto/Socket6/
%{_mandir}/man3/Socket6.3*

%changelog
* Fri Mar 24 2023 Paul Howarth <paul@city-fan.org> - 0.29-17
- Use SPDX-format license tag
- Aviod deprecated patch syntax

* Tue May 31 2022 Paul Howarth <paul@city-fan.org> - 0.29-14
- Perl 5.36 rebuild

* Wed Jul  7 2021 Paul Howarth <paul@city-fan.org> - 0.29-11
- Drop support for deprecated gethostbyname2
  https://src.fedoraproject.org/rpms/perl-Socket6/pull-request/2

* Fri May 21 2021 Paul Howarth <paul@city-fan.org> - 0.29-10
- Perl 5.34 rebuild

* Wed Jun 24 2020 Paul Howarth <paul@city-fan.org> - 0.29-7
- Perl 5.32 rebuild

* Thu May 30 2019 Paul Howarth <paul@city-fan.org> - 0.29-3
- Perl 5.30 rebuild

* Mon Oct  1 2018 Paul Howarth <paul@city-fan.org> - 0.29-1
- Update to 0.29
  - Socket6.xs: Update the tests for handling the correct headers on NetBSD
    and DragonFly BSD

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 0.28-7
- Perl 5.28 rebuild

* Sun Aug  6 2017 Paul Howarth <paul@city-fan.org> - 0.28-5
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Sun Jun  4 2017 Paul Howarth <paul@city-fan.org> - 0.28-3
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Mon Jul 11 2016 Paul Howarth <paul@city-fan.org> - 0.28-1
- Update to 0.28
  - aclocal.m4 (IPv6_CHECK_INET_NTOP): inet_ntop(3) may return an
    IPv4-compatible IPv6 address (CPAN RT#113950)
- BR: perl-generators where available

* Wed Mar 23 2016 Paul Howarth <paul@city-fan.org> - 0.27-1
- Update to 0.27
  - t/use.t: We still support an environment where AF_INET6 is not defined

* Fri Mar 18 2016 Paul Howarth <paul@city-fan.org> - 0.26-1
- Update to 0.26
  - gailookup.pl.in: Add -P option to ease specification of port number
  - gailookup.pl.in: Add awareness of AI_ALL and AI_V4MAPPED
  - gailookup.pl.in: Add -r option to do reverse lookup
  - System inet_ntop broken in darwin (CPAN RT#113005)
  - Makefile.PL: Make Socket6 buildable on Android (CPAN RT#98181)
- Simplify find commands using -delete
- Explicitly BR: perl-devel, needed for EXTERN.h

* Tue Jun 16 2015 Paul Howarth <paul@city-fan.org> - 0.25-6
- Perl 5.22 rebuild

* Thu May 21 2015 Paul Howarth <paul@city-fan.org> - 0.25-5
- Classify buildreqs by usage

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 0.25-4
- Drop %%defattr, redundant since rpm 4.4

* Mon Dec  9 2013 Paul Howarth <paul@city-fan.org> - 0.25-1
- Update to 0.25
  - t/use.t: Fixed test redefinition warnings (CPAN RT#75211)
  - Makefile.PL (configure_mswin32): Fixed undefined ref to inet_ntop,inet_pton
    on Windows XP (CPAN RT#65710)
  - Makefile.PL: Fixed passing perl cc and ccflags to configure (CPAN RT#77665)
  - Socket6.pm: Fixed typos (CPAN RT#71617, CPAN RT#86346)
  - Makefile.PL: Install manpage (CPAN RT#66811)

* Mon Jul 22 2013 Paul Howarth <paul@city-fan.org> - 0.23-14
- Perl 5.18 rebuild

* Tue Jun 12 2012 Paul Howarth <paul@city-fan.org> - 0.23-9
- BR: perl(base), perl(Carp), perl(Exporter), perl(Socket) and perl(Test)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Mon Jun 27 2011 Paul Howarth <paul@city-fan.org> - 0.23-7
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 0.23-6
- Rebuild for perl 5.12.1 in Rawhide

* Tue Jun  1 2010 Paul Howarth <paul@city-fan.org> - 0.23-5
- Fix dist tag for RHEL-6 Beta

* Wed Mar  3 2010 Paul Howarth <paul@city-fan.org> - 0.23-4
- Dist tag for Rawhide no longer needs special-casing

* Thu Sep 24 2009 Paul Howarth <paul@city-fan.org> - 0.23-3
- Use %%{?perl_default_filter} for provides filter

* Mon Mar  2 2009 Paul Howarth <paul@city-fan.org> - 0.23-2
- Filter out unwanted provides for perl shared objects
- Update to SLES-compatible dist tag macros

* Wed Nov  5 2008 Paul Howarth <paul@city-fan.org> - 0.23-1
- update to 0.23

* Mon Aug 18 2008 Paul Howarth <paul@city-fan.org> - 0.22-1
- update to 0.22
- tweak dist tag macros to work on current Rawhide with three-part releasenum

* Mon Feb 18 2008 Paul Howarth <paul@city-fan.org> - 0.20-1
- update to 0.20 (perl 5.10.x compatibility update)

* Fri Dec 21 2007 Paul Howarth <paul@city-fan.org> - 0.19-5
- import from Fedora
- fix argument order for find with -depth

* Tue Oct 16 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 0.19-4.1
- add BR: perl(ExtUtils::MakeMaker)

* Tue Aug 21 2007 Warren Togami <wtogami@redhat.com> - 0.19-4
- rebuild

* Wed Jul 12 2006 Warren Togami <wtogami@redhat.com> - 0.19-3
- import into FC6

* Thu May 18 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.19-2
- License: BSD (http://www.opensource.org/licenses/bsd-license.php).

* Sat May 13 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.19-1
- First build.
